@@ -1,7 +1,7 @@
 /* myhtmlparse.h: subclass of HtmlParser for extracting text
  *
  * Copyright 1999,2000,2001 BrightStation PLC
- * Copyright 2002,2003,2004,2006 Olly Betts
+ * Copyright 2002,2003,2004,2006,2008 Olly Betts
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -34,17 +34,32 @@ class MyHtmlParser : public HtmlParser {
 	bool in_script_tag;
 	bool in_style_tag;
 	bool pending_space;
-	string title, sample, keywords, dump;
 	bool indexing_allowed;
+	bool charset_from_meta;
+	string title, sample, keywords, dump;
 	void process_text(const string &text);
-	void opening_tag(const string &tag, const map<string,string> &p);
+	void opening_tag(const string &tag);
 	void closing_tag(const string &tag);
-	void parse_html(const string &text);
+	void parse_html(const string &text, const string &charset_,
+			bool charset_from_meta_);
 	MyHtmlParser() :
 		in_script_tag(false),
 		in_style_tag(false),
 		pending_space(false),
-		indexing_allowed(true) { }
+		indexing_allowed(true),
+		charset_from_meta(false) { }
+
+	void reset() {
+	    in_script_tag = false;
+	    in_style_tag = false;
+	    pending_space = false;
+	    indexing_allowed = true;
+	    charset_from_meta = false;
+	    title.resize(0);
+	    sample.resize(0);
+	    keywords.resize(0);
+	    dump.resize(0);
+	}
 };
 
 #endif // OMEGA_INCLUDED_MYHTMLPARSE_H
