@@ -346,13 +346,13 @@ try {
 
     parse_omegascript(); 
 } catch (const Xapian::Error &e) {
-    cout << "Exception: " << e.get_msg() << endl;
+    cout << "Exception: " << html_escape(e.get_msg()) << endl;
 } catch (const std::exception &e) {
-    cout << "Exception: std::exception " << e.what() << endl;
+    cout << "Exception: std::exception " << html_escape(e.what()) << endl;
 } catch (const string &s) {
-    cout << "Exception: " << s << endl;
+    cout << "Exception: " << html_escape(s) << endl;
 } catch (const char *s) {
-    cout << "Exception: " << s << endl;
+    cout << "Exception: " << html_escape(s) << endl;
 } catch (...) {
     cout << "Caught unknown exception" << endl;
 }
