@@ -17,11 +17,11 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  */
 
-#ifndef INCLUDED_UTF8CONVERT_H
-#define INCLUDED_UTF8CONVERT_H
+#ifndef OMEGA_INCLUDED_UTF8CONVERT_H
+#define OMEGA_INCLUDED_UTF8CONVERT_H
 
 #include <string>
 
 void convert_to_utf8(std::string & text, const std::string & charset);
 
-#endif
+#endif // OMEGA_INCLUDED_UTF8CONVERT_H
